Estimate the joint entropy of selected variables.
Arguments
- data
Observation data.
- indices
Integer vector of column indices to include in joint entropy calculation.
- base
(optional) Logarithm base of the entropy. Defaults to
exp(1)(nats). Use2for bits or10for dits.- type
(optional) Estimation method:
"disc"for discrete entropy or"cont"for continuous entropy (KSG estimator).- k
(optional) Number of nearest neighbors used by the continuous estimator. Ignored when
type = "disc".
Examples
infoxtr::je(matrix(1:100,ncol=2),1:2)
#> [1] 5.784231