Knockoff Conditional Mutual Information
Arguments
- data
Observation data.
- target
Integer vector of column indices for the target variables.
- agent
Integer vector of column indices for the source (agent) variables.
- conds
Integer vector of column indices for the conditioning variables.
- knockoff
Knockoff realizations constructed for the
agentvariable while keeping thetargetvariable unchanged. Each column corresponds to one Monte Carlo knockoff sample generated using the remaining variables except the target.- null_knockoff
(optional) Knockoff realizations generated under the null setting where all variables are jointly used to construct knockoffs. Each column represents one Monte Carlo sample. If
contain_null = FALSE, this argument can beNULL.- type
(optional) Estimation method:
"disc"for discrete mutual information or"cont"for continuous mutual information (KSG estimator).- nboots
(optional) Number of permutations used in the sign-flipping permutation test for evaluating the significance of the mean information difference.
- k
(optional) For
type = "cont", the number of nearest neighbors used by the continuous conditional mutual information estimator. Fortype = "disc", the number of bins used for discretization.- threads
(optional) Number of threads used.
- seed
(optional) Random seed used for permutation test.
- base
(optional) Logarithm base of the entropy. Defaults to
exp(1)(nats). Use2for bits or10for dits.- method
(optional) Discretization method. One of
"sd","equal","geometric","quantile","natural("jenks")", or"headtail"("headtails").- contain_null
(optional) Logical. If
TRUE, the test statistic is computed using knockoffs generated under the null model (provided innull_knockoff). In this case the difference is defined as \(I(Y; X_{null} | Z) - I(Y; X_{knockoff} | Z)\). IfFALSE, the original conditional mutual information \(I(Y; X | Z)\) is used instead and compared against the knockoff estimates \(I(Y; X_{knockoff} | Z)\).